#! /bin/sh
#----------------------------------------------------------------------------
# config.sh - configure fli4l router on the fly
#
# Creation:	13.04.2000  fm
# Last Update:  $Id: config.sh,v 1.3.2.3 2002/05/09 17:21:29 fm Exp $
#
# Copyright (c) 2000-2001 Frank Meyer
#----------------------------------------------------------------------------

write_resolv_conf ()
{
    echo "writing /etc/resolv.conf ..."

    if [ "$START_DNS" = "yes" ]
    then
	ipaddr=127.0.0.1				    # use 127.0.0.1
    else
	ipaddr="$DNS_FORWARDERS"
    fi

    (echo "#----------------------------------------------------------------------------"
     echo "# /etc/resolv.conf"
     echo "# automatically created by config.sh"
     echo "#----------------------------------------------------------------------------"
     echo "search $DOMAIN_NAME"
     for j in $ipaddr
     do
	 echo "nameserver $j"
     done
    ) >/etc/resolv.conf
}

write_pap_secrets ()
{
    echo "writing /etc/ppp/pap-secrets ..."

    (echo "#----------------------------------------------------------------------------"
     echo "# /etc/ppp/pap-secrets - secrets for authentication using PAP"
     echo "# automatically created by config.sh"
     echo "#"
     echo "# client	server	secret			IP addresses"
     echo "#----------------------------------------------------------------------------"

     idx=1

     while [ "$idx" -le "$ISDN_CIRCUITS_N" ]
     do
	type=`eval echo '$ISDN_CIRC_'$idx'_TYPE'`

	if [ "$type" = "ppp" ]
	then
	    user=`eval echo '$ISDN_CIRC_'$idx'_USER'`
	    pass=`eval echo '$ISDN_CIRC_'$idx'_PASS'`
	    server=`eval echo '$ISDN_CIRC_'$idx'_REMOTENAME'`

	    if [ "$server" != "" ]
	    then
		echo '"'"$user"'"'  "$server"  '"'"$pass"'"'
	    else
		echo '"'"$user"'"  *  "'"$pass"'"'
	    fi
	fi

	idx=`/usr/bin/expr $idx + 1`
    done) >/etc/ppp/pap-secrets
    chmod 600 /etc/ppp/pap-secrets
}

write_etc_hosts ()
{
    echo "writing /etc/hosts ..."

    (echo "#----------------------------------------------------------------------------"
     echo "# /etc/hosts"
     echo "# automatically created by config.sh"
     echo "#----------------------------------------------------------------------------"
     echo "127.0.0.1 localhost"

    i=1
    while [ $i -le $HOSTS_N ]
    do
	set `eval echo '$HOST_'$i`
	ipaddr=$1
	hostname=$2

	m=3
	max=$#
	while [ $m -le $max ]
	do
	    eval col='$'$m
	    case "$col"
	    in
		*:*)    ;;			    # skip mac address
		*)      hostname="$hostname $col";;
	    esac
	    m=`expr $m + 1`
	done

	echo "$ipaddr $hostname"
	i=`/usr/bin/expr $i + 1`
    done
    ) >/etc/hosts 
}

write_ens_conf ()
{
    echo "creating ENS configuration file ..."

    (
	echo logfile /ens.log

	serial=`date +%Y%m%d`				    # reverse date
     	echo "SOA $DOMAIN_NAME $HOSTNAME.$DOMAIN_NAME fli4l.$DOMAIN_NAME $serial 60 60 60 0"
	echo "NS $DOMAIN_NAME $HOSTNAME.$DOMAIN_NAME"
	echo "ZONE $DOMAIN_NAME"

	echo "127.0.0.1 localhost.$DOMAIN_NAME"

	i=1
	while [ $i -le $HOSTS_N ]
	do
	    set `eval echo '$HOST_'$i`
	    ipaddr=$1
	    hostname=$2

	    aliases=''
	    m=3
	    max=$#
	    while [ $m -le $max ]
	    do
		eval col='$'$m
		case "$col"
		in
		    *:*)    ;;				# skip mac address
		    *)      aliases="$aliases $col"
		esac
		m=`expr $m + 1`
	    done

	    echo "$ipaddr $hostname.$DOMAIN_NAME $aliases"

	    i=`/usr/bin/expr $i + 1`
	done

	echo 'PTR 1.0.0.127.in-addr.arpa localhost'

	i=1
	while [ $i -le $HOSTS_N ]
	do
	    set `eval echo '$HOST_'$i`
	    ipaddr=`echo $1 | sed 's/\./ /g'`
	    hostname=$2
	    set $ipaddr
	    rev=$4.$3.$2.$1

	    echo "PTR $rev.in-addr.arpa $hostname.$DOMAIN_NAME"
	    i=`/usr/bin/expr $i + 1`
	done

	i=1
	while [ $i -le $DNS_N ]
	do
	    dns="`eval echo '$DNS_'$i`"
	    set $dns				# $1=firma.de,  $2=192.168.1.12
	    echo "additional_forwarder $2 $1"
	    i=`/usr/bin/expr $i + 1`
	done

	for j in $DNS_FORWARDERS
	do
	    if [ "$j" != "0.0.0.0" ]
	    then
		echo "forwarder $j"
	    fi
	done

	echo 'forward_entry_timeout 50'
	echo 'forward_next_timeout 5'

	i=1
	while [ $i -le $DNS_FORBIDDEN_N ]
	do
	    forbidden="`eval echo '$DNS_FORBIDDEN_'$i`"
	    echo "forbidden $forbidden"
	    i=`/usr/bin/expr $i + 1`
	done

	i=1
	while [ $i -le $IP_ETH_N ]
	do
	    net=`eval echo '$IP_ETH_'$i'_NETWORK' '$IP_ETH_'$i'_NETMASK'`
	    dnet=`netcalc dnsnet $net`
	    rnet=`netcalc dnsrev $net`

	    echo "ACL dns.allow $dnet."
	    echo "ZONE $rnet"
	    i=`/usr/bin/expr $i + 1`
	done

	for netm in $MASQ_NETWORK $ROUTE_NETWORK
	do
	    dnetm=`netcalc dnsnet $netm`

	    found=false
	    i=1
	    while [ $i -le $IP_ETH_N ]
	    do
		net=`eval echo '$IP_ETH_'$i'_NETWORK' '$IP_ETH_'$i'_NETMASK'`
		dnet=`netcalc dnsnet $net`

		if [ $dnetm = $dnet ]
		then
		    found=true
		    break
		fi

		i=`/usr/bin/expr $i + 1`
	    done

	    if [ $found = "false" ]
	    then 
		echo "ACL dns.allow $dnetm."
		rnetm=`netcalc dnsrev $netm`
		echo "ZONE $rnetm"
	    fi
	done

	if [ "$OPT_PPP" = "yes" ]
	then
	    echo "ACL dns.allow $PPP_PEER"
	fi

	if [ "$OPT_MGETTY" = "yes" ]
	then
	    echo "ACL dns.allow $MGETTY_PEER"
	fi

	echo "ACL dns.allow 127.0.0.1"

	echo 'ACL dns.deny $'
	echo 'cache_max 10000'
    ) >/usr/local/ens/ens.conf

}

. /etc/rc.cfg

if [ ! -f /etc/resolv.conf ]				# already existing?
then							# yes, don't overwrite
    write_resolv_conf
fi

if [ ! -f /etc/ppp/pap-secrets ]			# already existing?
then							# yes, don't overwrite
    write_pap_secrets
fi

if [ ! -f /etc/ppp/chap-secrets ]			# already existing?
then							# yes, don't overwrite
    /bin/cat /etc/ppp/pap-secrets >/etc/ppp/chap-secrets
    chmod 600 /etc/ppp/chap-secrets
fi

if [ ! -f /etc/hosts ]					# already existing?
then							# yes, don't overwrite
    write_etc_hosts
fi

if [ -f /usr/local/ens/ens ]				# ens existing?
then							# yes, write config
    write_ens_conf
fi
